@@ -36,7 +36,7 @@ import tokenize
 import untokenize
 
 
-__version__ = '0.5.4'
+__version__ = '0.5.5'
 
 
 try:
@@ -194,7 +194,7 @@ def format_docstring(indentation, docstring,
 def reindent(text, indentation):
     """Return reindented text that matches indentation."""
     if '\t' not in indentation:
-        text = text.expandtabs(len(indentation))
+        text = text.expandtabs()
 
     text = textwrap.dedent(text)
 
@@ -249,7 +249,11 @@ def split_summary_and_description(contents):
 
 
 def split_first_sentence(text):
-    """Split text into first sentence and the rest."""
+    """Split text into first sentence and the rest.
+
+    Return a tuple (sentence, rest).
+
+    """
     sentence = ''
     rest = text
     delimiter = ''
@@ -294,7 +298,11 @@ def is_some_sort_of_list(text):
                               [0]):
         return True
 
-    return False
+    return (
+        re.search(r'\n\s*\n', text) or
+        re.search(r'[0-9]\.', text) or
+        re.search(r'[\-*:=@]', text)
+    )
 
 
 def _find_shortest_indentation(lines):
@@ -360,16 +368,12 @@ def wrap_description(text, indentation, wrap_length):
     if '>>>' in text:
         return text
 
+    text = remove_section_header(text)
+
     text = reindent(text, indentation).rstrip()
 
     # Ignore possibly complicated cases.
-    if (
-        wrap_length <= 0 or
-        re.search(r'\n\s*\n', text) or
-        re.search(r'[0-9]\.', text) or
-        re.search(r'[\-*:=]', text) or
-        is_some_sort_of_list(text)
-    ):
+    if wrap_length <= 0 or is_some_sort_of_list(text):
         return text
 
     return indentation + '\n'.join(
@@ -379,6 +383,29 @@ def wrap_description(text, indentation, wrap_length):
                       subsequent_indent=indentation)).strip()
 
 
+def remove_section_header(text):
+    r"""Return text with section header removed.
+
+    >>> remove_section_header('----\nfoo\nbar\n')
+    'foo\nbar\n'
+
+    >>> remove_section_header('===\nfoo\nbar\n')
+    'foo\nbar\n'
+
+    """
+
+    stripped = text.lstrip()
+    first = stripped[0]
+    if (
+        not first.isalnum() and
+        not first.isspace() and
+        not stripped.splitlines()[0].strip(first).strip()
+    ):
+        return stripped.lstrip(first).lstrip()
+
+    return text
+
+
 def strip_leading_blank_lines(text):
     """Return text with leading blank lines removed."""
     split = text.splitlines()
