@@ -879,10 +879,27 @@ Try this and this and this and this and this and this and this at
                 This should be dedented.
 
                 1. This too.
-        \t\t2. And this.
+        \t2. And this.
             """, indentation='    ')
         )
 
+    def test_reindent_with_no_indentation_expand_tabs(self):
+        self.assertEqual(
+            """\
+The below should be indented with spaces:
+
+        1. This too.
+        2. And this.
+""",
+            docformatter.reindent("""\
+The below should be indented with spaces:
+
+\t1. This too.
+\t2. And this.
+            """, indentation='')
+        )
+
+
     def test_reindent_should_maintain_indentation(self):
         description = """\
     Parameters:
@@ -916,6 +933,25 @@ Try this and this and this and this and this and this and this at
             docformatter.split_first_sentence(
                 'This is the first:\none\ntwo'))
 
+    def test_is_some_sort_of_list(self):
+        self.assertTrue(docformatter.is_some_sort_of_list("""\
+    @param
+    @param
+    @param
+"""))
+
+    def test_remove_section_header(self):
+        self.assertEqual(
+            'foo\nbar\n',
+            docformatter.remove_section_header('----\nfoo\nbar\n')
+        )
+
+        line = 'foo\nbar\n'
+        self.assertEqual(line, docformatter.remove_section_header(line))
+
+        line = '    \nfoo\nbar\n'
+        self.assertEqual(line, docformatter.remove_section_header(line))
+
 
 class TestSystem(unittest.TestCase):
 
